<?php

function image_file_name($id) {
    return sprintf('%s.jpg', str_pad($id, 6, '0', STR_PAD_LEFT));
}

function image_path($prefix, $id, $safe = TRUE) {
    $path = sprintf('%s/%s/%s', IMAGES_DIR, $prefix, image_file_name($id));
    if (! $safe || file_exists($path))
        return $path;
    else
        return sprintf('%s/%s/%s', IMAGES_DIR, $prefix, image_file_name(0));
}

function image_big_path($id, $safe = TRUE) {
    return image_path('big', $id, $safe);
}

function image_med_path($id, $safe = TRUE) {
    return image_path('med', $id, $safe);
}

function image_sml_path($id, $safe = TRUE) {
    return image_path('sml', $id, $safe);
}

function scaleImage($x, $y, $cx, $cy) {
    if ($cx <= $x || $cy <= $y) {
        if ($x > 0) $rx = $cx / $x;
        if ($y > 0) $ry = $cy / $y;

        if ($rx < $ry)
            $r = $rx;
        else
            $r = $ry;

        return array(intval($x * $r), intval($y * $r));
    } else
        return array($x, $y);
}

class Bitmap {
    protected $file;
    protected $width;
    protected $height;
    protected $format;

    public function __construct($file, $width, $height, $format = 'jpg') {
        $this->file = THIS_DIR . '/' . $file;
        $this->width = $width;
        $this->height = $height;
        $this->format = $format;
    }

    public function create($source, $proportional = TRUE) {
        $img = new Imagick($source);
        $img->stripImage();
        if ($proportional) {
            list($w, $h) = scaleImage($img->getImageWidth(), $img->getImageHeight(), $this->width, $this->height);
            $img->scaleImage($w, $h);
        } else
            $img->cropThumbnailImage($this->width, $this->height);
        $img->sharpenImage(1, 5);
        $img->setBackgroundColor('white');
        $img = $img->mergeImageLayers(Imagick::LAYERMETHOD_FLATTEN);
        $img->setImageFormat($this->format);
        if ($this->format == 'jpg')
            $img->setCompressionQuality(75);
        $img->writeImage($this->file);
        $img->clear();
        $img->destroy();
    }

    public function delete() {
        unlink($this->file);
    }
}

?>
